@@ -1,8 +1,10 @@
 from django.contrib import admin
 
-from models import Keycode
+from .models import Keycode
+
 
 class KeycodeAdmin(admin.ModelAdmin):
+
     list_display = ('site', 'provider', 'keycode', 'active',)
     list_editable = ('active',)
     search_fields = ['keycode']
